@@ -288,26 +288,27 @@ def roc_curve(source):
     Returns
     -------
     out : list
-        A list of ROC points, sorted by ascending min prob.
+        A list of ROC points.
     """
 
     parser = etree.XMLParser(remove_comments=True, ns_clean=True)
     tree = etree.parse(source, parser=parser)
 
     roc_curve = []
-    for roc_element in tree.xpath(
-        "/*[local-name()='msms_pipeline_analysis']"
-        "/*[local-name()='analysis_summary and @analysis='peptideprophet']"
-        "/*[local-name()='peptideprophet_summary']"
-        "/*[local-name()='roc_data_point']"):
-
-        roc_data_point = dict(roc_element.attrib)
-        for key in roc_data_point:
-            roc_data_point[key] = float(roc_data_point[key])
-        roc_curve.append(roc_data_point)
-
-    return sorted(roc_curve, key=lambda x: x['min_prob'])
+    for roc_error_data in tree.xpath(
+        "/*[local-name()='msms_pipeline_analysis'] \
+        //*[local-name()='analysis_summary' and @analysis='peptideprophet'] \
+        //*[local-name()='peptideprophet_summary'] \
+        //*[local-name()='roc_error_data']"):
+        for element in roc_error_data.xpath("*[local-name()='roc_data_point' or local-name()='error_point']"):
+            data_point = dict(element.attrib)
+            for key in data_point:
+                data_point[key] = float(data_point[key])
+            data_point["charge"] = roc_error_data.attrib["charge"]
+            data_point["tag"] = etree.QName(element).localname
+            roc_curve.append(data_point)
 
+    return roc_curve
 
 # chain = aux._make_chain(read, 'read')
 chain = aux.ChainBase._make_chain(read)
@@ -354,9 +355,13 @@ def DataFrame(*args, **kwargs):
 
     Parameters
     ----------
-    *args, **kwargs : passed to :py:func:`chain`
+    *args
+        Passed to :py:func:`chain`.
 
-    sep : str or None, optional
+    **kwargs
+        Passed to :py:func:`chain`.
+
+    sep : str or None, keyword only, optional
         Some values related to PSMs (such as protein information) are variable-length
         lists. If `sep` is a :py:class:`str`, they will be packed into single string using
         this delimiter. If `sep` is :py:const:`None`, they are kept as lists. Default is
@@ -430,12 +435,14 @@ def filter_df(*args, **kwargs):
 
     Parameters
     ----------
-    key : str / iterable / callable, optional
-        Default is 'expect'.
-    is_decoy : str / iterable / callable, optional
+    key : str / iterable / callable, keyword only, optional
+        PSM score. Default is 'expect'.
+    is_decoy : str / iterable / callable, keyword only, optional
         Default is to check if all strings in the "protein" column start with `'DECOY_'`
-
-    *args, **kwargs : passed to :py:func:`auxiliary.filter` and/or :py:func:`DataFrame`.
+    *args
+        Passed to :py:func:`auxiliary.filter` and/or :py:func:`DataFrame`.
+    **kwargs
+        Passed to :py:func:`auxiliary.filter` and/or :py:func:`DataFrame`.
 
     Returns
     -------
